# ExternalStorage

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**encrypt_options** | [**list[EncryptOption]**](EncryptOption.md) | encrypt info for external storage | [optional] 
**uri** | **str** | type of external storage, including s3, oss, gcs, ceph, nfs, pvc, etc. (related to runtime) | [default to '']

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


